@@ -1,52 +1,33 @@
 /*
- *   Copyright 2008 Montel Laurent <montel@kde.org>
+ *   SPDX-FileCopyrightText: 2008 Montel Laurent <montel@kde.org>
  *   based on kate session from sebas
- *   Copyright 2020  Alexander Lohnau <alexander.lohnau@gmx.de>
+ *   SPDX-FileCopyrightText: 2020 Alexander Lohnau <alexander.lohnau@gmx.de>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "konsoleprofiles.h"
 
 // KF
-#include <KIO/CommandLauncherJob>
 #include <KConfig>
 #include <KDirWatch>
+#include <KIO/CommandLauncherJob>
 #include <KLocalizedString>
 #include <KNotificationJobUiDelegate>
 // Qt
-#include <QFileInfo>
 #include <QDir>
+#include <QFileInfo>
 #include <QStandardPaths>
 
-
-KonsoleProfiles::KonsoleProfiles(QObject *parent, const QVariantList &args)
-    : Plasma::AbstractRunner(parent, args)
+KonsoleProfiles::KonsoleProfiles(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
+    : Plasma::AbstractRunner(parent, metaData, args)
 {
     setObjectName(QStringLiteral("Konsole Profiles"));
 
-    setIgnoredTypes(Plasma::RunnerContext::File
-                        | Plasma::RunnerContext::Directory
-                        | Plasma::RunnerContext::NetworkLocation);
-
     Plasma::RunnerSyntax s(QStringLiteral(":q:"), i18n("Finds Konsole profiles matching :q:."));
     s.addExampleQuery(QStringLiteral("konsole :q:"));
     addSyntax(s);
-    setDefaultSyntax(Plasma::RunnerSyntax(QStringLiteral("konsole"),
-                                          i18n("Lists all the Konsole profiles in your account.")));
+    addSyntax(Plasma::RunnerSyntax(QStringLiteral("konsole"), i18n("Lists all the Konsole profiles in your account.")));
 }
 
 KonsoleProfiles::~KonsoleProfiles() = default;
@@ -65,6 +46,7 @@ void KonsoleProfiles::init()
     connect(m_profileFilesWatch, &KDirWatch::deleted, this, &KonsoleProfiles::loadProfiles);
 
     loadProfiles();
+    setMinLetterCount(3);
 }
 
 void KonsoleProfiles::loadProfiles()
@@ -72,8 +54,7 @@ void KonsoleProfiles::loadProfiles()
     m_profiles.clear();
 
     QStringList profilesPaths;
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
-                                                       QStringLiteral("konsole"), QStandardPaths::LocateDirectory);
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("konsole"), QStandardPaths::LocateDirectory);
 
     for (const auto &dir : dirs) {
         const QStringList fileNames = QDir(dir).entryList({QStringLiteral("*.profile")});
@@ -102,19 +83,15 @@ void KonsoleProfiles::loadProfiles()
 void KonsoleProfiles::match(Plasma::RunnerContext &context)
 {
     QString term = context.query();
-    if (term.length() < 3 || !context.isValid()) {
-        return;
-    }
-
     term = term.remove(m_triggerWord).simplified();
-    for (const KonsoleProfileData &data: qAsConst(m_profiles)) {
+    for (const KonsoleProfileData &data : qAsConst(m_profiles)) {
         if (data.displayName.contains(term, Qt::CaseInsensitive)) {
             Plasma::QueryMatch match(this);
             match.setType(Plasma::QueryMatch::PossibleMatch);
             match.setIconName(data.iconName);
             match.setData(data.displayName);
             match.setText(QStringLiteral("Konsole: ") + data.displayName);
-            match.setRelevance((float) term.length() / (float) data.displayName.length());
+            match.setRelevance((float)term.length() / (float)data.displayName.length());
             context.addMatch(match);
         }
     }
@@ -124,9 +101,7 @@ void KonsoleProfiles::run(const Plasma::RunnerContext &context, const Plasma::Qu
     Q_UNUSED(context)
     const QString profile = match.data().toString();
 
-    auto *job = new KIO::CommandLauncherJob(QStringLiteral("konsole"), {
-        QStringLiteral("--profile"), profile
-    });
+    auto *job = new KIO::CommandLauncherJob(QStringLiteral("konsole"), {QStringLiteral("--profile"), profile});
     job->setDesktopName(QStringLiteral("org.kde.konsole"));
 
     auto *delegate = new KNotificationJobUiDelegate;
